# frozen_string_literal: true

namespace :heptapod do
  namespace :experimental do
    desc 'GitLab | Migrate to Native Hg'
    task :hg_migrate_native, [:project_id, :force] => [:gitlab_environment] do |task, args|
      args.with_default(force: false)
      project = Project.find(args[:project_id])

      unless project.mercurial?
        puts "abort: project is not a mercurial project".color(:red)
        exit(1)
      end

      if project.vcs_type == 'hg' && !args[:force]
        puts "abort: project is already migrated, use 'force' to migrate anyway".color(:red)
        exit(1)
      end

      check_gitaly_connection
      check_hgitaly_connection
      migrator = Heptapod::NativeMercurial::Migrator.new(project)
      migrator.migrate!
      puts 'done!'.color(:green)
    end
  end
end

def check_gitaly_connection
  storage_name = nil
  Gitlab.config.repositories.storages.each do |name, _details|
    storage_name = name
    Gitlab::GitalyClient::ServerService.new(name).info
  end
rescue GRPC::Unavailable => ex
  puts "Failed to connect to Gitaly...".color(:red)
  puts "Storage name: #{storage_name}"
  puts "Error: #{ex}"
  exit 1
end

def check_hgitaly_connection
  storage_name = nil
  Gitlab.config.repositories.storages.each do |name, _details|
    storage_name = name
    storage = Gitlab::GitalyClient.vcs_qualified_storage(name, 'hg')
    Gitlab::GitalyClient::ServerService.new(storage).info
  end
rescue GRPC::Unavailable => ex
  puts "Failed to connect to HGitaly...".color(:red)
  puts "Storage name: #{storage_name}"
  puts "Error: #{ex}"
  exit 1
end
